@@ -106,9 +106,9 @@ class WeChatWorkSDK(ValidationMixin):
                 "touser": "7683",
 
                 "msgtype": "text",
-                "agentid": 1000002,
+                "agentid": 1000041,
                 "text": {
-                    "content": "这是一条通知"
+                    "content": "🐅"
                 },
                 "safe": 0,
                 "enable_id_trans": 0,
@@ -135,18 +135,4 @@ class WeChatWorkSDK(ValidationMixin):
 
 
 if __name__ == '__main__':
-    data = {
-        "touser": "@all",
-
-        "msgtype": "text",
-        "agentid": 1000002,
-        "text": {
-            "content": "这是一条通知"
-        },
-        "safe": 0,
-        "enable_id_trans": 0,
-        "enable_duplicate_check": 0
-    }
-
-    we = WeChatWorkSDK('wwc18433f3075302e4', 'iL_8JXBoB5vFITCcOk2-EvP6TcOnVCjZI1LRw8vidtE')
-    we.request_api('post', '/message/send', query_params={}, data=data)
+    pass
